@@ -1,7 +1,7 @@
 // main.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2008, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -33,6 +33,15 @@
 #define darker(x)	dark(x)
 #endif
 
+#if QT_VERSION < 0x040500
+namespace Qt {
+const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
+#if QT_VERSION < 0x040200
+const WindowFlags CustomizeWindowHint   = WindowFlags(0x02000000);
+#endif
+}
+#endif
+
 
 //-------------------------------------------------------------------------
 // Singleton application instance stuff (Qt/X11 only atm.)
@@ -241,17 +250,81 @@ private:
 };
 
 
+//-------------------------------------------------------------------------
+// stacktrace - Signal crash handler.
+//
+
+#ifdef CONFIG_STACKTRACE
+#if defined(__GNUC__) && defined(Q_OS_LINUX)
+
+#include <errno.h>
+#include <signal.h>
+#include <sys/wait.h>
+
+void stacktrace ( int signo )
+{
+	pid_t pid;
+	int rc;
+	int status = 0;
+	char cmd[80];
+
+	// Reinstall default handler; prevent race conditions...
+	signal(signo, SIG_DFL);
+
+	static const char *shell  = "/bin/sh";
+	static const char *format = "gdb -q --batch --pid=%d --eval-command=bt";
+
+	snprintf(cmd, sizeof(cmd), format, (int) getpid());
+
+	pid = fork();
+
+	// Fork failure!
+	if (pid < 0)
+		return;
+
+	// Fork child...
+	if (pid == 0) {
+		execl(shell, shell, "-c", cmd, NULL);
+		_exit(1);
+		return;
+	}
+
+	// Parent here: wait for child to terminate...
+	do { rc = waitpid(pid, &status, 0); }
+	while ((rc < 0) && (errno == EINTR));
+
+	// Dispatch any logging, if any...
+	QApplication::processEvents(QEventLoop::AllEvents, 3000);
+
+	// Make sure everyone terminates...
+	kill(pid, SIGTERM);
+	_exit(1);
+}
+
+#endif
+#endif
+
+
 //-------------------------------------------------------------------------
 // main - The main program trunk.
 //
 
 int main ( int argc, char **argv )
 {
+#ifdef CONFIG_STACKTRACE
+#if defined(__GNUC__) && defined(Q_OS_LINUX)
+	signal(SIGILL,  stacktrace);
+	signal(SIGFPE,  stacktrace);
+	signal(SIGSEGV, stacktrace);
+	signal(SIGABRT, stacktrace);
+	signal(SIGBUS,  stacktrace);
+#endif
+#endif
 	qjackctlApplication app(argc, argv);
 
 	// Construct default settings; override with command line arguments.
 	qjackctlSetup settings;
-	if (!settings.parse_args(app.argc(), app.argv())) {
+	if (!settings.parse_args(app.arguments())) {
 		app.quit();
 		return 1;
 	}
@@ -298,17 +371,15 @@ int main ( int argc, char **argv )
 
 	// What style do we create these forms?
 	Qt::WindowFlags wflags = Qt::Window
-#if QT_VERSION >= 0x040200
 		| Qt::CustomizeWindowHint
-#endif
 		| Qt::WindowTitleHint
 		| Qt::WindowSystemMenuHint
-		| Qt::WindowMinMaxButtonsHint;
+		| Qt::WindowMinMaxButtonsHint
+		| Qt::WindowCloseButtonHint;
 	if (settings.bKeepOnTop)
 		wflags |= Qt::Tool;
 	// Construct the main form, and show it to the world.
 	qjackctlMainForm w(0, wflags);
-//	app.setMainWidget(&w);
 	w.setup(&settings);
 	// If we have a systray icon, we'll skip this.
 	if (!settings.bSystemTray) {
@@ -320,7 +391,6 @@ int main ( int argc, char **argv )
 	app.setMainWidget(&w);
 
 	// Register the quit signal/slot.
-	// app.connect(&app, SIGNAL(lastWindowClosed()), &app, SLOT(quit()));
 	app.setQuitOnLastWindowClosed(false);
 
 	return app.exec();
