@@ -1,7 +1,7 @@
 // qjackctlMainForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2008, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -51,6 +51,20 @@
 #include <QCustomEvent>
 #include <QCloseEvent>
 
+#if QT_VERSION < 0x040500
+namespace Qt {
+const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
+#if QT_VERSION < 0x040200
+const WindowFlags CustomizeWindowHint   = WindowFlags(0x02000000);
+#endif
+}
+#endif
+
+
+#ifdef CONFIG_DBUS
+#include <QDBusConnection>
+#endif
+
 #ifdef CONFIG_JACK_STATISTICS
 #include <jack/statistics.h>
 #endif
@@ -368,12 +382,11 @@ bool qjackctlMainForm::setup ( qjackctlSetup *pSetup )
 	// What style do we create these forms?
 	QWidget *pParent = NULL;
 	Qt::WindowFlags wflags = Qt::Window
-#if QT_VERSION >= 0x040200
 		| Qt::CustomizeWindowHint
-#endif
 		| Qt::WindowTitleHint
 		| Qt::WindowSystemMenuHint
-		| Qt::WindowMinMaxButtonsHint;
+		| Qt::WindowMinMaxButtonsHint
+		| Qt::WindowCloseButtonHint;
 	if (m_pSetup->bKeepOnTop) {
 		pParent = this;
 		wflags |= Qt::Tool;
@@ -477,6 +490,18 @@ bool qjackctlMainForm::setup ( qjackctlSetup *pSetup )
 		}
 	}
 #endif
+#ifdef CONFIG_DBUS
+	// Register D-Bus service...
+	if (m_pSetup->bDBusEnabled) {
+	//	QDBusConnection dbus = QDBusConnection::sessionBus();
+		QDBusConnection dbus = QDBusConnection::systemBus();
+		dbus.connect("", "", "org.rncbc.qjackctl", "start", 
+			this, SLOT(startJack()));
+		dbus.connect("", "", "org.rncbc.qjackctl", "stop", 
+			this, SLOT(stopJack()));
+	}
+#endif
+
 
 	// Load patchbay form recent paths...
 	if (m_pPatchbayForm) {
@@ -534,7 +559,7 @@ bool qjackctlMainForm::queryClose (void)
 			tr("Warning") + " - " QJACKCTL_SUBTITLE1,
 			tr("JACK is currently running.\n\n"
 			"Do you want to terminate the JACK audio server?"),
-			tr("Terminate"), tr("Cancel")) == 0);
+			QMessageBox::Ok | QMessageBox::Cancel) == QMessageBox::Ok);
 	}
 
 	// Try to save current aliases default settings.
@@ -673,17 +698,13 @@ void qjackctlMainForm::startJack (void)
 
 	// Is the server process instance still here?
 	if (m_pJack) {
-		switch (QMessageBox::warning(this,
+		if (QMessageBox::warning(this,
 			tr("Warning") + " - " QJACKCTL_SUBTITLE1,
 			tr("Could not start JACK.\n\n"
 			"Maybe JACK audio server is already started."),
-			tr("Stop"), tr("Kill"), tr("Cancel"))) {
-		case 0:
+			QMessageBox::Ok | QMessageBox::Cancel) == QMessageBox::Ok) {
 			m_pJack->terminate();
-			break;
-		case 1:
 			m_pJack->kill();
-			break;
 		}
 		return;
 	}
@@ -964,7 +985,7 @@ void qjackctlMainForm::stopJack (void)
 			tr("Some client audio applications\n"
 			"are still active and connected.\n\n"
 			"Do you want to stop the JACK audio server?"),
-			tr("Stop"), tr("Cancel")) > 0) {
+			QMessageBox::Yes | QMessageBox::No) == QMessageBox::No) {
 		return;
 	}
 	
@@ -1230,7 +1251,7 @@ void qjackctlMainForm::appendMessagesError( const QString& s )
 	appendMessagesColor(s.simplified(), "#ff0000");
 
 	QMessageBox::critical(this,
-		tr("Error") + " - " QJACKCTL_SUBTITLE1, s, tr("Cancel"));
+		tr("Error") + " - " QJACKCTL_SUBTITLE1, s, QMessageBox::Cancel);
 }
 
 
@@ -2004,7 +2025,7 @@ void qjackctlMainForm::queryDisconnect (
 			"Do you want to remove the patchbay connection?")
 			.arg(pCable->outputSocket()->name())
 			.arg(pCable->inputSocket()->name()),
-			tr("Remove"), tr("Ignore")) == 0) {
+			QMessageBox::Yes | QMessageBox::No) == QMessageBox::Yes) {
 			m_pPatchbayRack->removeCable(pCable);
 			if (m_pPatchbayForm
 				&& isActivePatchbay(m_pPatchbayForm->patchbayPath()))
@@ -2379,6 +2400,7 @@ void qjackctlMainForm::showSetupForm (void)
 		int     iOldMessagesLimitLines  = m_pSetup->iMessagesLimitLines;
 		bool    bOldBezierLines         = m_pSetup->bBezierLines;
 		bool    bOldAlsaSeqEnabled      = m_pSetup->bAlsaSeqEnabled;
+		bool    bOldDBusEnabled         = m_pSetup->bDBusEnabled;
 		bool    bOldAliasesEnabled      = m_pSetup->bAliasesEnabled;
 		bool    bOldAliasesEditing      = m_pSetup->bAliasesEditing;
 		bool    bOldLeftButtons         = m_pSetup->bLeftButtons;
@@ -2450,6 +2472,8 @@ void qjackctlMainForm::showSetupForm (void)
 				(!bOldDelayedSetup   &&  m_pSetup->bDelayedSetup)   ||
 				( bOldAlsaSeqEnabled && !m_pSetup->bAlsaSeqEnabled) ||
 				(!bOldAlsaSeqEnabled &&  m_pSetup->bAlsaSeqEnabled) ||
+				( bOldDBusEnabled    && !m_pSetup->bDBusEnabled)    ||
+				(!bOldDBusEnabled    &&  m_pSetup->bDBusEnabled)    ||
 				(iOldBaseFontSize    !=  m_pSetup->iBaseFontSize))
 				showDirtySetupWarning();
 			// If server is currently running, warn user...
@@ -2606,9 +2630,9 @@ void qjackctlMainForm::refreshStatus (void)
 			float fDspLoad = jack_cpu_load(m_pJackClient);
 			if (m_pSystemTray)
 				m_pSystemTray->setToolTip(
-					tr("%1 (%2%)").arg(windowTitle()).arg(fDspLoad, 0, 'g', 2));
+					tr("%1 (%2%)").arg(windowTitle()).arg(fDspLoad, 0, 'g', 3));
 			updateStatusItem(STATUS_DSP_LOAD,
-				tr("%1 %").arg(fDspLoad, 0, 'g', 2));
+				tr("%1 %").arg(fDspLoad, 0, 'g', 3));
 			updateStatusItem(STATUS_SAMPLE_RATE,
 				tr("%1 Hz").arg(jack_get_sample_rate(m_pJackClient)));
 			updateStatusItem(STATUS_BUFFER_SIZE,
@@ -2989,7 +3013,7 @@ void qjackctlMainForm::showDirtySettingsWarning (void)
 		QMessageBox::warning(this,
 			tr("Warning") + " - " QJACKCTL_SUBTITLE1,
 			tr("Server settings will be only effective after\n"
-			"restarting the JACK audio server."), tr("OK"));
+			"restarting the JACK audio server."));
 	}   // Otherwise, it will be just as convenient to update status...
 	else updateTitleStatus();
 }
@@ -3001,7 +3025,7 @@ void qjackctlMainForm::showDirtySetupWarning (void)
 	QMessageBox::information(this,
 		tr("Information") + " - " QJACKCTL_SUBTITLE1,
 		tr("Some settings will be only effective\n"
-		"the next time you start this program."), tr("OK"));
+		"the next time you start this program."));
 }
 
 
