@@ -1,7 +1,7 @@
 // qjackctlSetup.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2008, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -93,6 +93,7 @@ qjackctlSetup::qjackctlSetup (void)
 	bServerConfigTemp        = m_settings.value("/ServerConfigTemp", false).toBool();
 	bQueryShutdown           = m_settings.value("/QueryShutdown", true).toBool();
 	bAlsaSeqEnabled          = m_settings.value("/AlsaSeqEnabled", true).toBool();
+	bDBusEnabled             = m_settings.value("/DBusEnabled", false).toBool();
 	bAliasesEnabled          = m_settings.value("/AliasesEnabled", false).toBool();
 	bAliasesEditing          = m_settings.value("/AliasesEditing", false).toBool();
 	bLeftButtons             = m_settings.value("/LeftButtons", true).toBool();
@@ -185,6 +186,7 @@ qjackctlSetup::~qjackctlSetup (void)
 	m_settings.setValue("/ServerConfigTemp",        bServerConfigTemp);
 	m_settings.setValue("/QueryShutdown",           bQueryShutdown);
 	m_settings.setValue("/AlsaSeqEnabled",          bAlsaSeqEnabled);
+	m_settings.setValue("/DBusEnabled",             bDBusEnabled);
 	m_settings.setValue("/AliasesEnabled",          bAliasesEnabled);
 	m_settings.setValue("/AliasesEditing",          bAliasesEditing);
 	m_settings.setValue("/LeftButtons",             bLeftButtons);
@@ -326,7 +328,7 @@ bool qjackctlSetup::loadPreset ( qjackctlPreset& preset, const QString& sPreset
 	m_settings.endGroup();
 
 #ifdef CONFIG_JACK_MIDI
-	if (!preset.sMidiDriver.isEmpty() && 
+	if (!preset.sMidiDriver.isEmpty() &&
 		preset.sMidiDriver != "raw" &&
 		preset.sMidiDriver != "seq")
 		preset.sMidiDriver.clear();
@@ -404,7 +406,7 @@ bool qjackctlSetup::deletePreset ( const QString& sPreset )
 //
 
 // Help about command line options.
-void qjackctlSetup::print_usage ( const char *arg0 )
+void qjackctlSetup::print_usage ( const QString& arg0 )
 {
 	QTextStream out(stderr);
 	const QString sEot = "\n\t";
@@ -418,6 +420,8 @@ void qjackctlSetup::print_usage ( const char *arg0 )
 		QObject::tr("Start JACK audio server immediately") + sEol;
 	out << "  -p, --preset=[label]" + sEot +
 		QObject::tr("Set default settings preset name") + sEol;
+	out << "  -a, --active-patchbay=[path]" + sEot +
+		QObject::tr("Set active patchbay definition file") + sEol;
 	out << "  -h, --help" + sEot +
 		QObject::tr("Show help about command line options") + sEol;
 	out << "  -v, --version" + sEot +
@@ -426,30 +430,31 @@ void qjackctlSetup::print_usage ( const char *arg0 )
 
 
 // Parse command line arguments into m_settings.
-bool qjackctlSetup::parse_args ( int argc, char **argv )
+bool qjackctlSetup::parse_args ( const QStringList& args )
 {
 	QTextStream out(stderr);
 	const QString sEol = "\n\n";
 	int iCmdArgs = 0;
+	int argc = args.count();
 
 	for (int i = 1; i < argc; i++) {
 
 		if (iCmdArgs > 0) {
 			sCmdLine += ' ';
-			sCmdLine += argv[i];
+			sCmdLine += args.at(i);
 			iCmdArgs++;
 			continue;
 		}
 
-		QString sArg = argv[i];
+		QString sArg = args.at(i);
 		QString sVal = QString::null;
 		int iEqual = sArg.indexOf('=');
 		if (iEqual >= 0) {
 			sVal = sArg.right(sArg.length() - iEqual - 1);
 			sArg = sArg.left(iEqual);
 		}
-		else if (i < argc)
-			sVal = argv[i + 1];
+		else if (i < argc - 1)
+			sVal = args.at(i + 1);
 
 		if (sArg == "-s" || sArg == "--start") {
 			bStartJack = true;
@@ -463,8 +468,18 @@ bool qjackctlSetup::parse_args ( int argc, char **argv )
 			if (iEqual < 0)
 				i++;
 		}
+		else if (sArg == "-a" || sArg == "--active-patchbay") {
+			if (sVal.isNull()) {
+				out << QObject::tr("Option -a requires an argument (path).") + sEol;
+				return false;
+			}
+			bActivePatchbay = true;
+			sActivePatchbayPath = sVal;
+			if (iEqual < 0)
+				i++;
+		}
 		else if (sArg == "-h" || sArg == "--help") {
-			print_usage(argv[0]);
+			print_usage(args.at(0));
 			return false;
 		}
 		else if (sArg == "-v" || sArg == "--version") {
