@@ -1,7 +1,7 @@
 // qjackctlSetupForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2008, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -35,7 +35,6 @@
 
 #include <QButtonGroup>
 
-
 #ifdef CONFIG_COREAUDIO
 #include <iostream>
 #include <cstring>
@@ -44,6 +43,12 @@
 #include <CoreFoundation/CFString.h>
 #endif
 
+#ifdef CONFIG_PORTAUDIO
+#include <iostream>
+#include <cstring>
+#include <portaudio.h>
+#endif
+
 #ifdef CONFIG_ALSA_SEQ
 #include <alsa/asoundlib.h>
 #endif
@@ -98,6 +103,10 @@ qjackctlSetupForm::qjackctlSetupForm (
 	m_ui.MessagesLimitLinesComboBox->setValidator(
 		new QIntValidator(m_ui.MessagesLimitLinesComboBox));
 
+#if QT_VERSION >= 0x040200
+	m_ui.PresetComboBox->setCompleter(NULL);
+#endif
+
 	// UI connections...
 
 	QObject::connect(m_ui.PresetComboBox,
@@ -394,6 +403,9 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.AlsaSeqEnabledCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
+	QObject::connect(m_ui.DBusEnabledCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(optionsChanged()));
 	QObject::connect(m_ui.LeftButtonsCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
@@ -581,6 +593,7 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	m_ui.ServerConfigTempCheckBox->setChecked(m_pSetup->bServerConfigTemp);
 	m_ui.QueryShutdownCheckBox->setChecked(m_pSetup->bQueryShutdown);
 	m_ui.AlsaSeqEnabledCheckBox->setChecked(m_pSetup->bAlsaSeqEnabled);
+	m_ui.DBusEnabledCheckBox->setChecked(m_pSetup->bDBusEnabled);
 	m_ui.AliasesEnabledCheckBox->setChecked(m_pSetup->bAliasesEnabled);
 	m_ui.AliasesEditingCheckBox->setChecked(m_pSetup->bAliasesEditing);
 	m_ui.LeftButtonsCheckBox->setChecked(!m_pSetup->bLeftButtons);
@@ -603,9 +616,17 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	m_ui.MidiDriverTextLabel->setEnabled(false);
 	m_ui.MidiDriverComboBox->setEnabled(false);
 #endif
+#ifndef CONFIG_JACK_PORT_ALIASES
+	m_ui.JackClientPortAliasComboBox->setCurrentIndex(0);
+	m_ui.JackClientPortAliasTextLabel->setEnabled(false);
+	m_ui.JackClientPortAliasComboBox->setEnabled(false);
+#endif
 #ifndef CONFIG_ALSA_SEQ
 	m_ui.AlsaSeqEnabledCheckBox->setEnabled(false);
 #endif
+#ifndef CONFIG_DBUS
+	m_ui.DBusEnabledCheckBox->setEnabled(false);
+#endif
 
 	// Load preset list...
 	resetPresets();
@@ -772,17 +793,19 @@ void qjackctlSetupForm::changeCurrentPreset ( const QString& sPreset )
 			tr("Some settings have been changed:\n\n"
 			"\"%1\"\n\nDo you want to save the changes?")
 			.arg(m_sPreset),
-			tr("Save"), tr("Discard"), tr("Cancel"))) {
-		case 0: // Save...
+			QMessageBox::Save |
+			QMessageBox::Discard |
+			QMessageBox::Cancel)) {
+		case QMessageBox::Save:
 			savePreset(m_sPreset);
 			m_iDirtySetup++;
 			resetPresets();
 			setComboBoxCurrentText(m_ui.PresetComboBox, sPreset);
 			m_iDirtySetup--;
-		case 1: // Discard...
+		case QMessageBox::Discard:
 			m_iDirtySettings = 0;
 			break;
-		default:// Cancel...
+		default: // Cancel...
 			m_iDirtySetup++;
 			resetPresets();
 			setComboBoxCurrentText(m_ui.PresetComboBox, m_sPreset);
@@ -822,7 +845,7 @@ void qjackctlSetupForm::deleteCurrentPreset (void)
 		tr("Delete preset:\n\n"
 		"\"%1\"\n\nAre you sure?")
 		.arg(sPreset),
-		tr("OK"), tr("Cancel")) > 0)
+		QMessageBox::Ok | QMessageBox::Cancel) == QMessageBox::Cancel)
 		return;
 
 	if (deletePreset(sPreset)) {
@@ -885,14 +908,14 @@ void qjackctlSetupForm::changeDriverAudio ( const QString& sDriver, int iAudio )
 		break;
 	}
 
-	bEnabled = (bInEnabled && (bAlsa || bSun || bOss));
+	bEnabled = (bInEnabled && (bAlsa || bSun || bOss || bPortaudio));
 	m_ui.InDeviceTextLabel->setEnabled(bEnabled);
 	m_ui.InDeviceComboBox->setEnabled(bEnabled);
 	m_ui.InDeviceToolButton->setEnabled(bEnabled);
 	if (!bEnabled)
 		setComboBoxCurrentText(m_ui.InDeviceComboBox, m_pSetup->sDefPresetName);
 
-	bEnabled = (bOutEnabled && (bAlsa || bSun || bOss));
+	bEnabled = (bOutEnabled && (bAlsa || bSun || bOss || bPortaudio));
 	m_ui.OutDeviceTextLabel->setEnabled(bEnabled);
 	m_ui.OutDeviceComboBox->setEnabled(bEnabled);
 	m_ui.OutDeviceToolButton->setEnabled(bEnabled);
@@ -958,14 +981,14 @@ void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdat
 
 	m_ui.IgnoreHWCheckBox->setEnabled(bSun || bOss);
 
-#ifdef CONFIG_COREAUDIO
-	m_ui.PriorityTextLabel->setEnabled(false);
-	m_ui.PrioritySpinBox->setEnabled(false);
-#else
-	bool bPriorityEnabled = m_ui.RealtimeCheckBox->isChecked() && !bCoreaudio;
-	m_ui.PriorityTextLabel->setEnabled(bPriorityEnabled);
-	m_ui.PrioritySpinBox->setEnabled(bPriorityEnabled);
-#endif
+	if (bCoreaudio || bPortaudio) {
+		m_ui.PriorityTextLabel->setEnabled(false);
+		m_ui.PrioritySpinBox->setEnabled(false);
+	} else {
+		bool bPriorityEnabled = m_ui.RealtimeCheckBox->isChecked();
+		m_ui.PriorityTextLabel->setEnabled(bPriorityEnabled);
+		m_ui.PrioritySpinBox->setEnabled(bPriorityEnabled);
+	}
 
 	m_ui.PeriodsTextLabel->setEnabled(bAlsa || bSun || bOss || bFreebob || bFirewire);
 	m_ui.PeriodsSpinBox->setEnabled(bAlsa || bSun || bOss || bFreebob || bFirewire);
@@ -991,10 +1014,10 @@ void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdat
 					sOutDevice.isEmpty() || sOutDevice == m_pSetup->sDefPresetName);
 	}
 
-	bool bInterface = (bEnabled || bCoreaudio || bFreebob || bFirewire);
+	bool bInterface = (bEnabled || bCoreaudio || bFreebob || bFirewire || bPortaudio);
 	m_ui.InterfaceTextLabel->setEnabled(bInterface);
 	m_ui.InterfaceComboBox->setEnabled(bInterface);
-	m_ui.InterfaceToolButton->setEnabled(bEnabled || bCoreaudio);
+	m_ui.InterfaceToolButton->setEnabled(bEnabled || bCoreaudio || bPortaudio);
 	if (!bInterface)
 		setComboBoxCurrentText(m_ui.InterfaceComboBox, m_pSetup->sDefPresetName);
 
@@ -1177,7 +1200,10 @@ void qjackctlSetupForm::deviceMenu( QLineEdit *pLineEdit,
 	bool bOss       = (sDriver == "oss");
 #ifdef CONFIG_COREAUDIO
 	bool bCoreaudio = (sDriver == "coreaudio");
-	std::map<QString,AudioDeviceID> coreaudioIdMap;
+	std::map<QString, AudioDeviceID> coreaudioIdMap;
+#endif
+#ifdef CONFIG_PORTAUDIO
+	bool bPortaudio = (sDriver == "portaudio");
 #endif
 	QString sCurName = pLineEdit->text();
 	QString sName, sSubName;
@@ -1300,7 +1326,7 @@ void qjackctlSetupForm::deviceMenu( QLineEdit *pLineEdit,
 #ifdef CONFIG_COREAUDIO
 	else if (bCoreaudio) {
 		// Find out how many Core Audio devices are there, if any...
-		// (code snippet gently "borrowed" from St?hane Letz jackdmp;)
+		// (code snippet gently "borrowed" from Stephane Letz jackdmp;)
 		OSStatus err;
 		Boolean isWritable;
 		UInt32 outSize = sizeof(isWritable);
@@ -1353,6 +1379,29 @@ void qjackctlSetupForm::deviceMenu( QLineEdit *pLineEdit,
 		}
 	}
 #endif 	// CONFIG_COREAUDIO
+#ifdef CONFIG_PORTAUDIO
+	else if (bPortaudio) {
+		if (Pa_Initialize() == paNoError) {
+			// Fill hostapi info...
+            PaHostApiIndex iNumHostApi = Pa_GetHostApiCount();
+            QString *pHostName = new QString[iNumHostApi];
+            for (PaHostApiIndex i = 0; i < iNumHostApi; ++i)
+                pHostName[i] = QString(Pa_GetHostApiInfo(i)->name);
+			// Fill device info...
+            PaDeviceIndex iNumDevice = Pa_GetDeviceCount();
+            PaDeviceInfo **ppDeviceInfo = new PaDeviceInfo * [iNumDevice];
+            for (PaDeviceIndex i = 0; i < iNumDevice; ++i) {
+            	ppDeviceInfo[i] = const_cast<PaDeviceInfo *> (Pa_GetDeviceInfo(i));
+				sText = pHostName[ppDeviceInfo[i]->hostApi] + "::" + QString(ppDeviceInfo[i]->name);
+				pAction = menu.addAction(sText);
+				pAction->setCheckable(true);
+				pAction->setChecked(sCurName == sText);
+				++iCards;
+			}
+			Pa_Terminate();
+		}
+	}
+#endif  // CONFIG_PORTAUDIO
 
 	// There's always the default device...
 	if (iCards > 0)
@@ -1737,6 +1786,7 @@ void qjackctlSetupForm::accept (void)
 		m_pSetup->bServerConfigTemp        = m_ui.ServerConfigTempCheckBox->isChecked();
 		m_pSetup->bQueryShutdown           = m_ui.QueryShutdownCheckBox->isChecked();
 		m_pSetup->bAlsaSeqEnabled          = m_ui.AlsaSeqEnabledCheckBox->isChecked();
+		m_pSetup->bDBusEnabled             = m_ui.DBusEnabledCheckBox->isChecked();
 		m_pSetup->bAliasesEnabled          = m_ui.AliasesEnabledCheckBox->isChecked();
 		m_pSetup->bAliasesEditing          = m_ui.AliasesEditingCheckBox->isChecked();
 		m_pSetup->bLeftButtons             = !m_ui.LeftButtonsCheckBox->isChecked();
@@ -1776,11 +1826,13 @@ void qjackctlSetupForm::reject (void)
 			tr("Warning") + " - " QJACKCTL_SUBTITLE1,
 			tr("Some settings have been changed.\n\n"
 			"Do you want to apply the changes?"),
-			tr("Apply"), tr("Discard"), tr("Cancel"))) {
-		case 0:     // Apply...
+			QMessageBox::Apply |
+			QMessageBox::Discard |
+			QMessageBox::Cancel)) {
+		case QMessageBox::Apply:
 			accept();
 			return;
-		case 1:     // Discard
+		case QMessageBox::Discard:
 			break;
 		default:    // Cancel.
 			bReject = false;
